@@ -1,5 +1,5 @@
-# This code is part of Perl distribution OODoc version 3.02.
-# The POD got stripped from this file by OODoc version 3.02.
+# This code is part of Perl distribution OODoc version 3.03.
+# The POD got stripped from this file by OODoc version 3.03.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2003-2025 by Mark Overmeer.
@@ -14,7 +14,7 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package OODoc;{
-our $VERSION = '3.02';
+our $VERSION = '3.03';
 }
 
 use parent 'OODoc::Object';
@@ -22,12 +22,13 @@ use parent 'OODoc::Object';
 use strict;
 use warnings;
 
-our $VERSION = '3.02';  # needed here for own release process
+our $VERSION = '3.03';  # needed here for own release process
 
 use Log::Report    'oodoc';
 
 use OODoc::Manifest ();
 use OODoc::Format   ();
+use OODoc::Index    ();
 
 use File::Basename        qw/dirname/;
 use File::Copy            qw/copy move/;
@@ -62,6 +63,7 @@ sub init($)
 	$self->{O_version} = $version
 		or error __x"no version specified for distribution {dist}", dist  => $distribution;
 
+	$self->{O_index}   = OODoc::Index->new;
 	$self;
 }
 
@@ -77,6 +79,9 @@ sub version() { $_[0]->{O_version} }
 
 sub project() { $_[0]->{O_project} }
 
+
+sub index() { $_[0]->{O_index} }
+
 #--------------------
 
 sub selectFiles($@)
@@ -199,8 +204,8 @@ sub processFiles(@)
 		eval "require $parser";
 		$@ and error __x"cannot compile {pkg} class: {err}", pkg => $parser, err => $@;
 
-		$parser = $parser->new(skip_links => delete $args{skip_links})
-			or error __x"parser {name} could not be instantiated", name=> $parser;
+		$parser = $parser->new(skip_links => delete $args{skip_links}, index => $self->index)
+			or error __x"parser {name} could not be instantiated", name => $parser;
 	}
 
 	#
@@ -233,7 +238,7 @@ sub processFiles(@)
 		trace $_->stats for @manuals;
 
 		foreach my $man (@manuals)
-		{	$self->addManual($man) if $man->chapters;
+		{	$self->index->addManual($man) if $man->chapters;
 		}
 	}
 
@@ -248,14 +253,16 @@ sub finalize(%)
 	info "* collect package relations";
 	$self->getPackageRelations;
 
+	my @manuals = $self->index->manuals;
+
 	info "* expand manual contents";
-	$_->expand for $self->manuals;
+	$_->expand for @manuals;
 
 	info "* create inheritance chapters";
-	$_->createInheritance for $self->manuals;
+	$_->createInheritance for @manuals;
 
 	info "* finalize each manual";
-	$_->finalize(%args) for $self->manuals;
+	$_->finalize(%args) for @manuals;
 
 	$self;
 }
@@ -265,7 +272,7 @@ sub prepare() { panic "OODoc 3.01 renamed prepare() into finalize." }
 
 sub getPackageRelations($)
 {	my $self    = shift;
-	my @manuals = $self->manuals;  # all
+	my @manuals = $self->index->manuals;  # all
 
 	info "compiling all packages";
 
@@ -279,27 +286,28 @@ sub getPackageRelations($)
 	}
 
 	info "detect inheritance relationships";
+	my $index = $self->index;
 
 	foreach my $manual (@manuals)
 	{
 		trace "  relations for $manual";
 
 		if($manual->name ne $manual->package)  # autoloaded code
-		{	my $main = $self->mainManual("$manual");
+		{	my $main = $index->mainManual("$manual");
 			$main->extraCode($manual) if defined $main;
 			next;
 		}
 		my %uses = $manual->collectPackageRelations;
 
 		foreach (defined $uses{isa} ? @{$uses{isa}} : ())
-		{	my $isa = $self->mainManual($_) || $_;
+		{	my $isa = $index->mainManual($_) || $_;
 
 			$manual->superClasses($isa);
 			$isa->subClasses($manual) if blessed $isa;
 		}
 
 		if(my $realizes = $uses{realizes})
-		{	my $to  = $self->mainManual($realizes) || $realizes;
+		{	my $to  = $index->mainManual($realizes) || $realizes;
 
 			$manual->realizes($to);
 			$to->realizers($manual) if blessed $to;
@@ -333,6 +341,7 @@ sub formatter($@)
 		workdir     => $dest,
 		project     => $self->distribution,
 		version     => $self->version,
+		index       => $self->index,
 	);
 }
 
@@ -341,9 +350,8 @@ sub create() { panic 'Interface change in 2.03: use $oodoc->formatter->createPag
 
 sub stats()
 {	my $self = shift;
-	my @manuals  = $self->manuals;
-	my $manuals  = @manuals;
-	my $realpkg  = $self->packageNames;
+	my @manuals  = $self->index->manuals;
+	my $realpkg  = $self->index->packageNames;
 
 	my $subs     = map $_->subroutines, @manuals;
 	my @options  = map { map $_->options, $_->subroutines } @manuals;
@@ -352,10 +360,11 @@ sub stats()
 	my $diags    = map $_->diagnostics, @manuals;
 	my $version  = $self->version;
 	my $project  = $self->project;
+	my $nr_mans  = @manuals;
 
 	<<__STATS;
 Project $project contains:
-  Number of package manuals: $manuals
+  Number of package manuals: $nr_mans
   Real number of packages:   $realpkg
   documented subroutines:    $subs
   documented options:        $options
